==> alfresco-repository-23.3.16.1-sources.jar: org/alfresco/repo/action/AsynchronousActionExecutionQueue.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.action;

import java.util.Set;

import org.alfresco.service.cmr.action.Action;
import org.alfresco.service.cmr.repository.NodeRef;

/**
 * Asynchronous action execution queue
 * 
 * @author Roy Wetherall
 */
public interface AsynchronousActionExecutionQueue
{
    /**
     * @param actionService RuntimeActionService
     * @param action Action
     * @param actionedUponNodeRef NodeRef
     * @param checkConditions boolean
     */
    void executeAction(
            RuntimeActionService actionService,
            Action action,
            NodeRef actionedUponNodeRef,
            boolean checkConditions,
            Set<String> actionChain);
    
}

==> alfresco-repository-26.1.0.16-sources.jar: org/alfresco/repo/action/AsynchronousActionExecutionQueue.java <==
/*
 * #%L
 * Alfresco Repository
 * %%
 * Copyright (C) 2005 - 2016 Alfresco Software Limited
 * %%
 * This file is part of the Alfresco software. 
 * If the software was purchased under a paid Alfresco license, the terms of 
 * the paid license agreement will prevail.  Otherwise, the software is 
 * provided under the following open source license terms:
 * 
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 * #L%
 */
package org.alfresco.repo.action;

import java.util.Set;

import org.alfresco.service.cmr.action.Action;
import org.alfresco.service.cmr.repository.NodeRef;

/**
 * Asynchronous action execution queue
 * 
 * @author Roy Wetherall
 */
public interface AsynchronousActionExecutionQueue
{
    /**
     * @param actionService
     *            RuntimeActionService
     * @param action
     *            Action
     * @param actionedUponNodeRef
     *            NodeRef
     * @param checkConditions
     *            boolean
     */
    void executeAction(
            RuntimeActionService actionService,
            Action action,
            NodeRef actionedUponNodeRef,
            boolean checkConditions,
            Set<String> actionChain);

}
